#include "locale_marker.h"
#include "authority/game_state.h"
#include "core/config/engine.h"
#include "core/input/input_enums.h"
#include "macros.h"

void LocaleMarker::_bind_methods() {
	BIND_HPROPERTY(Variant::STRING, locale_scene, PROPERTY_HINT_FILE, "*.tscn,*.scn");
}

void LocaleMarker::_notification(int what) {
	if(Engine::get_singleton()->is_editor_hint()) {
		return;
	}
	switch(what) {
	default: return;
	case NOTIFICATION_READY:
		this->ready();
		return;
	}
}

void LocaleMarker::ready() {
	this->connect(this->sig_input_event, callable_mp(this, &self_type::on_input_event));
}

void LocaleMarker::on_input_event(Node *camera, Ref<InputEvent> event, Vector3 position, Vector3 normal, int shape_ind) {
	Ref<InputEventMouseButton> clicked{event};
	if(clicked.is_valid() && clicked->get_button_index() == MouseButton::LEFT) {
		GameState::get_singleton()->set_locale_entrance_path(this->entrance_path);
		GameState::get_singleton()->set_locale_uid(locale_scene);
	}
}

void LocaleMarker::set_locale_scene(String const &path) {
	this->locale_scene = path;
}

String LocaleMarker::get_locale_scene() const {
	return this->locale_scene;
}

void LocaleMarker::set_entrance_path(String const &node_path) {
	this->entrance_path = node_path;
}

String LocaleMarker::get_entrance_path() const {
	return this->entrance_path;
}
